aclhs.vario_params: Set parameters for computing a Variogram.
Description
Sets specific parameters for computing Variograms within the acLHS 1D or 2D
function calls. Note that the lag value computed for Variograms will always
be the 'minimum' of the independent data (i.e., for 1D minimum time between
points and for 2D minimum distance between points).
Usage
aclhs.vario_params(num_lags = 8, dir = 0, tol = 90, min_pairs = 1)
## Store the parameters into a variablev_params <- aclhs.vario_params(num_lags=10, dir=0, tol=90, min_pairs=1)
## Access one of the the set parametersv_params$num_lags